pub enum JsonValue {
Object(JsonObject),
Array(JsonArray),
String(JsonString),
Number(JsonNumber),
Boolean(JsonBoolean),
Null(JsonNull),
}Expand description
Represents any valid JSON value.
Variants
Object(JsonObject)
A JSON object (collection of key-value pairs).
Array(JsonArray)
A JSON array (ordered list of values).
String(JsonString)
A JSON string.
Number(JsonNumber)
A JSON number (represented as f64).
Boolean(JsonBoolean)
A JSON boolean (true or false).
Null(JsonNull)
A JSON null value.
Implementations
Sourceimpl JsonValue
impl JsonValue
Sourcepub fn as_array(&self) -> Option<&JsonArray>
pub fn as_array(&self) -> Option<&JsonArray>
Returns the value as a reference to a JsonArray, if it is an array.
Sourcepub fn as_object(&self) -> Option<&JsonObject>
pub fn as_object(&self) -> Option<&JsonObject>
Returns the value as a reference to a JsonObject, if it is an object.